@@ -16,10 +16,11 @@ def main():
     parser = argparse.ArgumentParser(description='Extract reference files for nominated species')
     parser.add_argument('imgt_file', help='gapped imgt reference file')
     parser.add_argument('species_name', help='species name for IMGT file in quotes, e.g. "Homo sapiens", "Macaca mulatta"')
+    parser.add_argument('-F', '--functional_only', action='store_true')
     args = parser.parse_args()
 
     segs = ['IGHV', 'IGHD', 'IGHJ', 'CH']
-    refs = simple.read_imgt_fasta(args.imgt_file, [args.species_name], segs)
+    refs = simple.read_imgt_fasta(args.imgt_file, [args.species_name], segs, functional_only=args.functional_only)
 
     simple.write_fasta(refs[args.species_name]['IGHV'], '%s_IGHV_gapped.fasta' %args.species_name.replace(' ', '_'))
 
